@@ -17,7 +17,13 @@ from zenroom import zencode_exec
 
 
 from transactions.types.assets.create import Create
+from transactions.types.assets.compose import Compose
 from transactions.common.utils import _fulfillment_to_details
+from transactions.common.utils import _fulfillment_from_details
+from transactions.common.transaction import (
+    Input,
+    TransactionLink,
+)
 
 
 def make_ed25519_condition(public_key, *, amount=1):
@@ -246,9 +252,14 @@ def alice_transaction(alice_transaction_obj):
 
 
 @fixture
-def signed_alice_transaction(alice_privkey, alice_transaction_obj):
+def signed_alice_transaction_not_dict(alice_privkey, alice_transaction_obj):
     signed_transaction = alice_transaction_obj.sign([alice_privkey])
-    return signed_transaction.to_dict()
+    return signed_transaction
+
+
+@fixture
+def signed_alice_transaction(signed_alice_transaction_not_dict):
+    return signed_alice_transaction_not_dict.to_dict()
 
 
 @fixture
@@ -275,6 +286,57 @@ def persisted_random_transaction(alice_pubkey, alice_privkey):
     return tx.sign([alice_privkey]).to_dict()
 
 
+@fixture
+def compose_asset_cid():
+    return "QmW5GVMW98D3mktSDfWHS8nX2UiCd8gP1uCiujnFX4yK8n"
+
+
+@fixture
+def persisted_compose_transaction(signed_alice_transaction, alice_pubkey, compose_asset_cid):
+    condition_index = 0
+    condition = signed_alice_transaction["outputs"][condition_index]
+    inputs_ = [
+        Input(
+            _fulfillment_from_details(condition["condition"]["details"]),
+            condition["public_keys"],
+            fulfills=TransactionLink(
+                txid=signed_alice_transaction["id"],
+                output=condition_index,
+            ),
+        )
+    ]
+    assets_ = [signed_alice_transaction["id"], compose_asset_cid]
+    compose_transaction = Compose.generate(inputs=inputs_, recipients=[([alice_pubkey], 1)], assets=assets_)
+    return compose_transaction
+
+
+@fixture
+def persisted_decompose_transaction(signed_alice_transaction, alice_pubkey, compose_asset_cid):
+    from planetmint_driver.offchain import prepare_decompose_transaction
+
+    condition_index = 0
+    condition = signed_alice_transaction["outputs"][condition_index]
+    inputs_ = [
+        Input(
+            _fulfillment_from_details(condition["condition"]["details"]),
+            condition["public_keys"],
+            fulfills=TransactionLink(
+                txid=signed_alice_transaction["id"],
+                output=condition_index,
+            ),
+        )
+    ]
+    assets_ = [
+        signed_alice_transaction["id"],
+        "bafkreiawyk3ou5qzqec4ggbvrs56dv5ske2viwprf6he5wj5gr4yv5orsu",
+        "bafkreibncbonglm6mi3znbrqbchk56wmgftk4gfevxqlgeif3g5jdotcka",
+        "bafkreibkokzihpnnyqf3xslcievqkadf2ozkdi72wyibijih447vq42kjm",
+    ]
+    recipients = [([alice_pubkey], 1), ([alice_pubkey], 2), ([alice_pubkey], 3)]
+    decompose_transaction = prepare_decompose_transaction(inputs=inputs_, recipients=recipients, assets=assets_)
+    return decompose_transaction
+
+
 @fixture
 def sent_persisted_random_transaction(alice_pubkey, alice_privkey, transactions_api_full_url):
     from uuid import uuid4
@@ -295,7 +357,7 @@ def block_with_alice_transaction(sent_persisted_random_transaction, blocks_api_f
     return requests.get(
         blocks_api_full_url,
         params={"transaction_id": sent_persisted_random_transaction["id"]},
-    ).json()[0]
+    ).json()[0][2]
 
 
 @fixture
@@ -564,7 +626,7 @@ def search_assets():
 @fixture
 def text_search_assets(api_root, transactions_api_full_url, alice_pubkey, alice_privkey, search_assets):
     # check if the fixture was already executed
-    response = requests.get(api_root + "/assets", params={"search": "planetmint"})
+    response = requests.get(api_root + "/assets/planetmint")
     response = response.json()
     if len(response) == 3:
         assets = []
