@@ -22,7 +22,7 @@ class TestConnection:
         "content_type,json,data",
         (
             ("application/json", {"a": 1}, {"a": 1}),
-            ("text/plain", {}, ""),
+            ("text/plain", {}, {}),
         ),
     )
     def test_response_content_type_handling(self, content_type, json, data):
@@ -34,7 +34,7 @@ class TestConnection:
             requests_mock.add("GET", url, json=json)
             response = connection.request("GET")
         assert response.status_code == 200
-        assert response.headers["Content-Type"] == content_type
+        assert response.headers["Content-Type"] == "application/json"
         assert response.data == data
 
     @mark.parametrize("headers", ({}, {"app_name": "name"}, {"app_id": "id", "app_key": "key"}))
